@@ -240,7 +240,7 @@ class Motor(MotorDatabase):
 class Redis(redis.StrictRedis):
 
     def __init__(self, **kwargs):
-        if any([key in kwargs for key in ['host', 'port', 'password', 'db']]):
+        if any([key in kwargs for key in ['host', 'port', 'password']]):
             host = kwargs.pop('host', 'localhost')
             port = kwargs.pop('port', 6379)
             password = kwargs.pop('password', None)
@@ -275,7 +275,7 @@ class Redis(redis.StrictRedis):
 class AioRedis(aredis.StrictRedis):
 
     def __init__(self, **kwargs):
-        if any([key in kwargs for key in ['host', 'port', 'password', 'db']]):
+        if any([key in kwargs for key in ['host', 'port', 'password']]):
             host = kwargs.pop('host', 'localhost')
             port = kwargs.pop('port', 6379)
             password = kwargs.pop('password', None)
@@ -311,7 +311,7 @@ class Mysql:
 
     def __init__(self, time_zone='+08:00', max_idle_time=7 * 3600, charset='utf8',
                  sql_mode='TRADITIONAL', autocommit=True, **kwargs):
-        if any([key in kwargs for key in ['host', 'port', 'password', 'db']]):
+        if any([key in kwargs for key in ['host', 'port', 'password']]):
             host = kwargs.pop('host', 'localhost')
             port = kwargs.pop('port', 3306)
             user = kwargs.pop('user', None)
@@ -384,7 +384,16 @@ class Mysql:
         self._ensure_connected()
         cursor = self._conn.cursor()
         try:
-            return cursor.execute(sql, args)
+            cursor.execute(sql, args)
+            return self.lastrowid
+        finally:
+            cursor.close()
+
+    def executemany(self, sql, args):
+        self._ensure_connected()
+        cursor = self._conn.cursor()
+        try:
+            return cursor.executemany(sql, args)
         finally:
             cursor.close()
 
@@ -455,6 +464,15 @@ class AioMysql(Mysql):
         await self._ensure_connected()
         cursor = await self._conn.cursor()
         try:
-            return await cursor.execute(sql, args)
+            await cursor.execute(sql, args)
+            return self._lastrowid
+        finally:
+            await cursor.close()
+
+    async def executemany(self, sql, args):
+        await self._ensure_connected()
+        cursor = await self._conn.cursor()
+        try:
+            return await cursor.executemany(sql, args)
         finally:
             await cursor.close()
